@@ -584,7 +584,7 @@ class ContentNode(object):
         :param str existing_tag_name: The name of the existing tag whose values will be copied to the new tag.
         :param str new_tag_name: The name of the new tag.  This must be different from the existing_tag_name.
         """
-        if existing_tag_name == None or new_tag_name == None or existing_tag_name == new_tag_name:
+        if existing_tag_name is None or new_tag_name is None or existing_tag_name == new_tag_name:
             return  # do nothing, just exit function
 
         for node in self.select(selector):
@@ -598,7 +598,7 @@ class ContentNode(object):
                     previous_uuid = None
                     new_uuid = None
                     for val in sorted_tag_values:
-                        if previous_uuid == None or previous_uuid != val['uuid']:
+                        if previous_uuid is None or previous_uuid != val['uuid']:
                             new_uuid = str(uuid.uuid4())
 
                         previous_uuid = val['uuid']
@@ -757,7 +757,7 @@ class ContentNode(object):
             for child_node in node_to_check.children:
                 result = tag_node_position(child_node, start, end, node_data, tag_uuid)
                 content_length = content_length + result
-                if result < 0:
+                if result < 0 or (end - result) < 0:
                     return -1
                 else:
                     end = end - result
@@ -827,6 +827,46 @@ class ContentNode(object):
 
         return values
 
+    def get_related_tag_values(self, tag_name: str, include_children: bool = False, value_separator: str = ' '):
+        """
+        Get the values for a specific tag name, grouped by uuid
+
+        :param tag_name: tag name
+        :param include_children: include the children of this node
+        :param value_separator: the string to be used to join related tag values
+        :return: a list of the tag values
+        """
+
+        def group_tag_values(group_dict, feature_val):
+            # we know the names of all these tags are the same, but we want to group them if they share the same uuid
+            if feature_val['uuid'] in value_groups.keys():
+                # we've seen this UUID - add it's value to the group
+                group_dict[feature_val['uuid']].append(feature_val['value'])
+            else:
+                # first occurrence
+                group_dict[feature_val['uuid']] = [feature_val['value']]
+
+        if include_children:
+            tagged_nodes = self.select('//*[hasTag("' + tag_name + '")]')
+        else:
+            tagged_nodes = self.select('.')
+
+        value_groups: Dict[str, Any] = {}
+        for tag_node in tagged_nodes:
+            tag_feature_vals = tag_node.get_feature_value('tag', tag_name)
+            if tag_feature_vals:
+                if not isinstance(tag_feature_vals, list):
+                    tag_feature_vals = [tag_feature_vals]
+
+                for v in tag_feature_vals:
+                    group_tag_values(value_groups, v)
+
+        value_strings = []
+        for k in value_groups.keys():
+            value_strings.append(value_separator.join(value_groups[k]))
+
+        return value_strings
+
     def get_tag(self, tag_name):
         """
         Returns the value of a tag, this can be either a single list [start,end,value] or if multiple parts of the
@@ -1288,6 +1328,12 @@ class SourceMetadata:
     # noting that multiple documents coming from an original source
     lineage_document_uuid: Optional[str] = None
 
+    # The UUID of the original first document
+    source_document_uuid: Optional[str] = None
+
+    # The UUID of the document in a PDF form (used for archiving and preview)
+    pdf_document_uuid: Optional[str] = None
+
     @classmethod
     def from_dict(cls, env):
         return cls(**{
@@ -1697,7 +1743,7 @@ class DocumentStore:
         from rich.table import Table
         from rich import print
 
-        table = Table(title=f"Listing Objects")
+        table = Table(title="Listing Objects")
 
         cols = ['id', 'content_type', 'path']
         for col in cols:
